===========================
Welcome to django-modeltree
===========================

.. image:: https://img.shields.io/badge/python-3.6%20%7C%203.7%20%7C%203.8%20%7C%203.9%20%7C%203.10-blue
   :target: https://img.shields.io/badge/python-3.6%20%7C%203.7%20%7C%203.8%20%7C%203.9%20%7C%203.10-blue
   :alt: python: 3.6, 3.7, 3.8, 3.9, 3.10

.. image:: https://img.shields.io/badge/django-2.2%20%7C%203.0%20%7C%203.1%20%7C%203.2%20%7C%204.0%20%7C%204.1-orange
   :target: https://img.shields.io/badge/django-2.2%20%7C%203.0%20%7C%203.1%20%7C%203.2%20%7C%204.0%20%7C%204.1-orange
   :alt: django: 2.2, 3.0, 3.1, 3.2, 4.0, 4.1

.. image:: https://github.com/thomst/django-modeltree/actions/workflows/ci.yml/badge.svg
   :target: https://github.com/thomst/django-modeltree/actions/workflows/ci.yml
   :alt: Run tests for django-modeltree

.. image:: https://coveralls.io/repos/github/thomst/django-modeltree/badge.svg?branch=master
   :target: https://coveralls.io/github/thomst/django-modeltree?branch=master
   :alt: Coveralls


Description
===========
A ModelTree describes a django model and all its recursive relations to other
models. It is Node based, iterable, walkable, searchable and can be populated
by model items. See the `docs <https://thomst.github.io/django-modeltree/>`_.


Links
=====

* `Repository <https://github.com/thomst/django-modeltree>`_
* `Documentation <https://thomst.github.io/django-modeltree/>`_


Installation
============
Install from pypi.org::

    pip install django-modeltree
